apikey='Vwtn1qlQiGdCQArxdTgRYTirQdeZVtVBjFar2Dup45R1'
instance_crn='crn%3Av1%3Abluemix%3Apublic%3Asql-query%3Aus-south%3Aa%2Fd86af7367f70fba4f306d3c19c938f2f%3Ad1b2c005-e3d8-48c0-9247-e9726a7ed510%3A%3A'
instance_rate_limit=10
result_location='cos://us-south/sqltempregional/'
eu_instance_crn='crn%3Av1%3Abluemix%3Apublic%3Asql-query%3Aeu-de%3Aa%2Fd86af7367f70fba4f306d3c19c938f2f%3A853c2c4e-7073-4081-8cca-f6451b01fda7%3A%3A'
eu_result_location='cos://eu-de/sqltempregionaleu/'